@@ -335,12 +335,10 @@ class VCloudConnection(ConnectionUserAndKey):
 
     def _get_auth_token(self):
         if not self.token:
-            conn = self.conn_classes[self.secure](self.host,
-                                                  self.port)
-            conn.request(method='POST', url='/api/v0.8/login',
-                         headers=self._get_auth_headers())
+            self.connection.request(method='POST', url='/api/v0.8/login',
+                                    headers=self._get_auth_headers())
 
-            resp = conn.getresponse()
+            resp = self.connection.getresponse()
             headers = dict(resp.getheaders())
             body = ET.XML(resp.read())
 
@@ -829,12 +827,10 @@ class VCloud_1_5_Connection(VCloudConnection):
     def _get_auth_token(self):
         if not self.token:
             # Log In
-            conn = self.conn_classes[self.secure](self.host,
-                                                  self.port)
-            conn.request(method='POST', url='/api/sessions',
-                         headers=self._get_auth_headers())
+            self.connection.request(method='POST', url='/api/sessions',
+                                    headers=self._get_auth_headers())
 
-            resp = conn.getresponse()
+            resp = self.connection.getresponse()
             headers = dict(resp.getheaders())
 
             # Set authorization token
@@ -852,9 +848,11 @@ class VCloud_1_5_Connection(VCloudConnection):
                      'application/vnd.vmware.vcloud.orgList+xml')).get('href')
             )
 
-            conn.request(method='GET', url=org_list_url,
-                         headers=self.add_default_headers({}))
-            body = ET.XML(conn.getresponse().read())
+            if self.proxy_url:
+                self.connection.set_http_proxy(self.proxy_url)
+            self.connection.request(method='GET', url=org_list_url,
+                                    headers=self.add_default_headers({}))
+            body = ET.XML(self.connection.getresponse().read())
             self.driver.org = get_url_path(
                 next((org for org in body.findall(fixxpath(body, 'Org'))
                      if org.get('name') == self.org_name)).get('href')
